@@ -5,7 +5,7 @@
 # Joan Ntzougani, gravitalsun@hotmail.com
 
 package Dancer2::Plugin::WebService;
-our	$VERSION = '4.3.3';
+our	$VERSION = '4.3.4';
 use	strict;
 use	warnings;
 use Encode;
@@ -601,13 +601,13 @@ $plg->dsl->halt( $plg->reply_text )
 
 
 
-#  Returns a list/hash of all or the selected keys
+#  Return a list/hash of all or the selected posted keys
 #
-#	           PosteData();              # all                posted keys/values
-#	my %DATA = PosteData('k1', 'k2');    # hash with selected posted keys/values
-#   my @DATA = PosteData('k1', 'k2');    # list with selected posted keys/values
+#	           PostData();              # all                posted keys/values
+#	my %DATA = PostData('k1', 'k2');    # hash with selected posted keys/values
+#   my @DATA = PostData('k1', 'k2');    # list with selected posted keys/values
 #
-sub PosteData :PluginKeyword
+sub PostData :PluginKeyword
 {
 my $plg=shift;
 
@@ -772,7 +772,7 @@ Dancer2::Plugin::WebService - RESTful Web Services with login, persistent data,
 
 =head1 VERSION
 
-version 4.3.3
+version 4.3.4
 
 =head1 SYNOPSIS
 
@@ -801,11 +801,11 @@ The replies through this module have the extra key B<error> . At success B<error
   use     Dancer2;
   use     Dancer2::Plugin::WebService;
 
-  post '/AllKeys'  => sub { reply   PosteData            };
-  post '/SomeKeys' => sub { reply   PosteData('k1','k2') };
+  post '/AllKeys'  => sub { reply   PostData            };
+  post '/SomeKeys' => sub { reply   PostData('k1','k2') };
   get  '/data1'    => sub { reply  'k1'=>'v1','k2'=>'v2' };
   get  '/data2'    => sub { reply {'k1'=>'v1','k2'=>'v2'}};
-  any  '/data3'    => sub { my %H = PosteData('k1', 'k2');
+  any  '/data3'    => sub { my %H = PostData('k1', 'k2');
                       reply 'foo'=> $H{k1}, 'boo'=>$H{k2}
                       };
   get  '/error'             => sub { reply 'k1', 'v1', 'error', 'oups' };
@@ -861,7 +861,7 @@ I<from> default is the I<config.yml> property
 
 Your routes can be either B<public> or B<protected>
 
-B<public> are the routes that anyone can use without B<login> , Τhey do not support sessions / persistent data, but you can post and access data using the method B<PosteData>
+B<public> are the routes that anyone can use without B<login> , Τhey do not support sessions / persistent data, but you can access the posted data using the method B<PostData>
 
 B<protected> are the routes that you must provide a token, returned by the login route.
 At B<protected> routes you can  I<read>, I<write>, I<delete> persistent data using the  methods B<session_get> , B<session_set> , B<session_del>
@@ -972,15 +972,15 @@ This should be the last route's statement
   reply( { k1 => 'v1', ... } ) anything you want
   reply   'k1'                 The specific key and its value of the posted data 
 
-=head2 PosteData
+=head2 PostData
 
 I<public method>
 
-Get the data posted by the user
+Get the posted data
 
-             PosteData               Everything posted
-  my %hash = PosteData('k2','k4');   Only some keys  of a hash
-  my @list = PosteData('k2','k4');   Only some items of a list
+             PostData               Everything posted
+  my %hash = PostData('k2','k4');   Only some keys  of a hash
+  my @list = PostData('k2','k4');   Only some items of a list
 
 The posted data can be anything; hashes, lists, scalars
 
